@@ -1,8 +1,10 @@
-/* A Bison parser, made by GNU Bison 2.7.12-4996.  */
 
-/* Bison interface for Yacc-like parsers in C
+/* A Bison parser, made by GNU Bison 2.4.1.  */
+
+/* Skeleton interface for Bison's Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,15 +32,6 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
-#ifndef YY_FF2_FFILTER_FFILTER_GRAM_H_INCLUDED
-# define YY_FF2_FFILTER_FFILTER_GRAM_H_INCLUDED
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 0
-#endif
-#if YYDEBUG
-extern int ff2_debug;
-#endif
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -70,11 +63,13 @@ extern int ff2_debug;
 
 
 
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-/* Line 2053 of yacc.c  */
-#line 48 "ffilter/ffilter_gram.y"
+
+/* Line 1676 of yacc.c  */
+#line 48 "ffilter_gram.y"
 
 	uint64_t	t_uint;
 	double		t_double;
@@ -82,8 +77,9 @@ typedef union YYSTYPE
 	void		*node;
 
 
-/* Line 2053 of yacc.c  */
-#line 87 "ffilter/ffilter_gram.h"
+
+/* Line 1676 of yacc.c  */
+#line 83 "ffilter/ffilter_gram.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
@@ -91,18 +87,5 @@ typedef union YYSTYPE
 #endif
 
 
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int ff2_parse (void *YYPARSE_PARAM);
-#else
-int ff2_parse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
-int ff2_parse (yyscan_t scanner, ff_t *filter);
-#else
-int ff2_parse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
-#endif /* !YY_FF2_FFILTER_FFILTER_GRAM_H_INCLUDED  */
+
